#-----------------------------------------------------------------------
# File    : makefile    (directory: nass)
# Contents: build neuron assembly program
# Author  : Christian Borgelt
# History : 2008.08.27 file created
#           2008.10.05 adapted to utility and math modules
#           2016.04.20 completed dependencies on header files
#-----------------------------------------------------------------------
THISDIR  = ..\..\nass\src
UTILDIR  = ..\..\util\src
MATHDIR  = ..\..\math\src

CC       = cl.exe
DEFS     = /D WIN32 /D NDEBUG /D _CONSOLE /D _CRT_SECURE_NO_WARNINGS
CFLAGS   = /nologo /W3 /O2 /GS- $(DEFS) /c
INCS     = /I $(UTILDIR) /I $(MATHDIR)

LD       = link.exe
LDFLAGS  = /nologo /subsystem:console /incremental:no
LIBS     = 

HDRS     = $(UTILDIR)\fntypes.h $(UTILDIR)\arrays.h
OBJS     = $(UTILDIR)\arrays.obj $(UTILDIR)\random.obj \
           trials.obj nass.obj
PRGS     = nass.exe

#-----------------------------------------------------------------------
# Build Programs
#-----------------------------------------------------------------------
all:        $(PRGS)

nass.exe:   $(OBJS) nass.mak
	$(LD) $(LDFLAGS) $(OBJS) $(LIBS) /out:$@

#-----------------------------------------------------------------------
# Main Programs
#-----------------------------------------------------------------------
nass.obj:     $(HDRS) $(UTILDIR)\random.h  trials.h
nass.obj:     nass.c nass.mak
	$(CC) $(CFLAGS) $(INCS) nass.c /Fo$@

#-----------------------------------------------------------------------
# Trial and Trial Set Management
#-----------------------------------------------------------------------
trials.obj:   $(HDRS)
trials.obj:   trials.h trials.c nass.mak
	$(CC) $(CFLAGS) $(INCS) trials.c /Fo$@

#-----------------------------------------------------------------------
# External Modules
#-----------------------------------------------------------------------
$(UTILDIR)\arrays.obj:
	cd $(UTILDIR)
	$(MAKE) /f util.mak arrays.obj
	cd $(THISDIR)
$(UTILDIR)\random.obj:
	cd $(UTILDIR)
	$(MAKE) /f util.mak random.obj
	cd $(THISDIR)

#-----------------------------------------------------------------------
# Install
#-----------------------------------------------------------------------
install:
	-@copy *.exe ..\..\..\bin

#-----------------------------------------------------------------------
# Clean up
#-----------------------------------------------------------------------
localclean:
	-@erase /Q *~ *.obj *.idb *.pch $(PRGS)

clean:
	$(MAKE) /f nass.mak localclean
	cd $(UTILDIR)
	$(MAKE) /f util.mak clean
	cd $(MATHDIR)
	$(MAKE) /f math.mak clean
	cd $(THISDIR)
